@@ -7,10 +7,15 @@ gemspec
 
 group :maintenance, optional: true do
 	gem "bake-modernize"
-	gem "bake-bundler"
+	gem "bake-gem"
+	
+	gem "utopia-project", "~> 0.18"
 end
 
 group :test do
+	gem "bake-test"
+	gem "bake-test-external"
+	
 	gem 'async-io'
 	gem 'async-rspec'
 end
