@@ -101,22 +101,27 @@ module Protocol
 			# An array of `[key, value]` pairs.
 			attr :fields
 			
-			# @return the trailer if there are any.
+			# @returns Whether there are any trailers.
 			def trailer?
 				@tail != nil
 			end
 			
-			# Record the current headers, and prepare to receive trailer.
+			# Record the current headers, and prepare to add trailers.
+			#
+			# This method is typically used after headers are sent to capture any
+			# additional headers which should then be sent as trailers.
+			#
+			# A sender that intends to generate one or more trailer fields in a
+			# message should generate a trailer header field in the header section of
+			# that message to indicate which fields might be present in the trailers.
+			#
+			# @parameter names [Array] The trailer header names which will be added later.
+			# @yields block {|name, value| ...} The trailer headers if any.
+			# @returns An enumerator which is suitable for iterating over trailers.
 			def trailer!(&block)
-				return nil unless self.include?(TRAILER)
-				
 				@tail ||= @fields.size
 				
-				return to_enum(:trailer!) unless block_given?
-				
-				if @tail
-					@fields.drop(@tail).each(&block)
-				end
+				return trailer(&block)
 			end
 			
 			# Enumerate all headers in the trailer, if there are any.
@@ -152,6 +157,8 @@ module Protocol
 				self[key] != nil
 			end
 			
+			alias key? include?
+			
 			def keys
 				self.to_h.keys
 			end
@@ -335,11 +342,11 @@ module Protocol
 					return self
 				end
 				
-				# @yield [String, String] header key (lower case) and value (as string).
+				# @yields [String, String] header key (lower case string) and value (as string).
 				def each(&block)
 					@all.each do |headers|
 						headers.each do |key, value|
-							yield key.downcase, value.to_s
+							yield key.to_s.downcase, value.to_s
 						end
 					end
 				end
