@@ -20,20 +20,11 @@
 # OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN
 # THE SOFTWARE.
 
-require_relative '../headers'
+require_relative '../middleware'
 
 module Protocol
 	module HTTP
 		class Middleware
-			module NotFound
-				def self.close
-				end
-				
-				def self.call(request)
-					Response[404, Headers[], []]
-				end
-			end
-			
 			class Builder
 				def initialize(default_app = NotFound)
 					@use = []
